@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Scalar::Util qw/reftype/;
 use Carp qw/croak/;
@@ -33,7 +33,7 @@ sub _merge {
 	my ($self, $new, $merger) = @_;
 	return $new unless defined $merger;
 
-	my $new_ref = reftype($new);
+	my $new_ref = reftype($new) || '';
 	my $merger_ref = reftype($merger) // reftype(\$merger);
 	if ( $merger_ref eq 'SCALAR' ) {
 		return $merger;
@@ -89,7 +89,7 @@ Blessed::Merge - Merge Blessed Refs.
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
